@@ -89,7 +89,7 @@ static int csdb_open_tempdb(dbhandle *db)
     return 0;
 }
 
-static int csdb_open(dbhandle *db, const char *file, enum mode mode)
+static int csdb_open(dbhandle *db, char *file, enum mode mode)
 {
     int openmode = mode & MODE_READDB ? O_RDONLY : O_RDWR | O_CREAT;
 
@@ -204,7 +204,8 @@ static int checksum_calc(checksum_t *checksum, const char *file)
     long _crc = 0;
     FILE *fp;
 
-    memset(checksum, 0, sizeof checksum);
+    // Clear any padding between the fields
+    memset(checksum, 0, sizeof(checksum_t));
 
     fp = fopen (file, "rb");
     if (fp == NULL) {
