@@ -226,7 +226,7 @@ static int read_backward(struct scores *s, int outfd)
 	return 0;
 
     read_count = bufsize;
-    if (s->offset < bufsize)
+    if (s->offset < (off_t)bufsize)
 	read_count = (ssize_t)s->offset;
     if (max_reverse < read_count)
 	read_count = max_reverse;
@@ -364,7 +364,7 @@ int main(int argc, char **argv)
 	bufsize = max_reverse;
     buf = malloc(bufsize);
     if (!buf) {
-	fprintf(stderr, "Failed to allocate %u bytes of memory\n", bufsize);
+	fprintf(stderr, "Failed to allocate %zu bytes of memory\n", bufsize);
 	return 1;
     }
 
